@@ -191,13 +191,14 @@ class EventManager:
                 debug.println(debug.LEVEL_INFO, msg, True)
                 return True
 
-        if event.type.startswith('object:text-changed') and event.type.endswith('system'):
+        if event.type.startswith('object:text-changed') \
+           and self.EMBEDDED_OBJECT_CHARACTER in event.any_data \
+           and not event.any_data.replace(self.EMBEDDED_OBJECT_CHARACTER, ""):
             # We should also get children-changed events telling us the same thing.
             # Getting a bunch of both can result in a flood that grinds us to a halt.
-            if event.any_data == self.EMBEDDED_OBJECT_CHARACTER:
-                msg = 'EVENT MANAGER: Ignoring because changed text is embedded object'
-                debug.println(debug.LEVEL_INFO, msg, True)
-                return True
+            msg = 'EVENT MANAGER: Ignoring because changed text is only embedded objects'
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
 
         try:
             # TODO - JD: For now we won't ask for the name. Simply asking for the name should
@@ -446,9 +447,13 @@ class EventManager:
             except:
                 toolkitName = None
             if toolkitName in self._synchronousToolkits \
-               or isinstance(e, input_event.MouseButtonEvent) \
-               or e.type.startswith("object:children-changed"):
+               or isinstance(e, input_event.MouseButtonEvent):
                 asyncMode = False
+            elif e.type.startswith("object:children-changed"):
+                try:
+                    asyncMode = e.source.getRole() == pyatspi.ROLE_TABLE
+                except:
+                    asyncMode = True
             script = _scriptManager.getScript(app, e.source)
             script.eventCache[e.type] = (e, time.time())
 
@@ -787,6 +792,7 @@ class EventManager:
                   "object:text-changed:insert",
                   "object:text-changed:delete:system",
                   "object:text-changed:insert:system",
+                  "object:text-attributes-changed",
                   "object:children-changed:add",
                   "object:children-changed:add:system",
                   "object:property-change:accessible-name",
@@ -815,6 +821,7 @@ class EventManager:
                   "object:text-changed:insert",
                   "object:text-changed:delete:system",
                   "object:text-changed:insert:system",
+                  "object:text-attributes-changed",
                   "object:children-changed:add",
                   "object:children-changed:add:system",
                   "object:property-change:accessible-name",
@@ -836,6 +843,9 @@ class EventManager:
         if event.type.startswith("object:state-changed:selected"):
             return event.detail1
 
+        if event.type.startswith("object:text-selection-changed"):
+            return True
+
         if event.type.startswith("window:activate"):
             return True
 
