@@ -75,6 +75,21 @@ AUTO_FOCUS_MODE_STRUCT_NAV = _("Automatic focus mode during structural navigatio
 # of the entry.
 AUTO_FOCUS_MODE_CARET_NAV = _("Automatic focus mode during caret navigation")
 
+# Translators: Orca has a number of commands that override the default behavior
+# within an application. For instance, if you are at the bottom of an entry and
+# press Down arrow, should you leave the entry? It depends on if you want to
+# resume reading content or if you are editing the text in the entry. Because
+# Orca doesn't know what you want to do, it has two modes: In browse mode, Orca
+# treats key presses as commands to read the content; in focus mode, Orca treats
+# key presses as something that should be handled by the focused widget. Orca
+# optionally can attempt to detect which mode is appropriate for the current
+# situation and switch automatically. This string is a label for a GUI option to
+# enable such automatic switching when native navigation commands are used.
+# Here "native" means "not Orca"; it could be a browser navigation command such
+# as the Tab key, or it might be a web page behavior, such as the search field
+# automatically gaining focus when the page loads.
+AUTO_FOCUS_MODE_NATIVE_NAV = _("Automatic focus mode during native navigation")
+
 # Translators: A single braille cell on a refreshable braille display consists
 # of 8 dots. Dot 7 is the dot in the bottom left corner. If the user selects 
 # this option, Dot 7 will be used to 'underline' text of interest, e.g. when
@@ -108,7 +123,7 @@ BTN_OK = _("_OK")
 # presenting a capital letter (which Speech Dispatcher refers to as 'spell'),
 # or play a tone (which Speech Dispatcher refers to as a sound 'icon'.) This
 # string to be translated appears as a combo box item in Orca's Preferences.
-CAPITALIZATION_STYLE_ICON = C_("capitalization style", "icon")
+CAPITALIZATION_STYLE_ICON = C_("capitalization style", "Icon")
 
 # Translators: Orca uses Speech Dispatcher to present content to users via
 # text-to-speech. Speech Dispatcher has a feature to control how capital
@@ -116,7 +131,7 @@ CAPITALIZATION_STYLE_ICON = C_("capitalization style", "icon")
 # presenting a capital letter (which Speech Dispatcher refers to as 'spell'),
 # or play a tone (which Speech Dispatcher refers to as a sound 'icon'.) This
 # string to be translated appears as a combo box item in Orca's Preferences.
-CAPITALIZATION_STYLE_NONE = C_("capitalization style", "none")
+CAPITALIZATION_STYLE_NONE = C_("capitalization style", "None")
 
 # Translators: Orca uses Speech Dispatcher to present content to users via
 # text-to-speech. Speech Dispatcher has a feature to control how capital
@@ -124,7 +139,7 @@ CAPITALIZATION_STYLE_NONE = C_("capitalization style", "none")
 # presenting a capital letter (which Speech Dispatcher refers to as 'spell'),
 # or play a tone (which Speech Dispatcher refers to as a sound 'icon'.) This
 # string to be translated appears as a combo box item in Orca's Preferences.
-CAPITALIZATION_STYLE_SPELL = C_("capitalization style", "spell")
+CAPITALIZATION_STYLE_SPELL = C_("capitalization style", "Spell")
 
 # Translators: If this checkbox is checked, then Orca will tell you when one of
 # your buddies is typing a message.
@@ -244,10 +259,10 @@ FIND_ONLY_SPEAK_CHANGED_LINES = _("Onl_y speak changed lines during find")
 # Firefox.
 FIND_SPEAK_RESULTS = _("Speak results during _find")
 
-# Translators: Function is a table column header where the cells in the column
+# Translators: Command is a table column header where the cells in the column
 # are a sentence that briefly describes what action Orca will take if and when
 # the user invokes that keyboard command.
-KB_HEADER_FUNCTION = _("Function")
+KB_HEADER_FUNCTION = _("Command")
 
 # Translators: Key Binding is a table column header where the cells in the
 # column represent keyboard combinations the user can press to invoke Orca
@@ -371,14 +386,6 @@ PROFILE_SAVE_AS_TITLE = _("Save Profile As")
 # name of a new settings profile being saved via the 'Save Profile As' dialog.
 PROFILE_NAME_LABEL = _("_Profile Name:")
 
-# Translators: Profiles in Orca make it possible for users to quickly switch
-# amongst a group of pre-defined settings (e.g. an 'English' profile for reading
-# text written in English using an English-language speech synthesizer and
-# braille rules, and a similar 'Spanish' profile for reading Spanish text.
-# The following is a title in a dialog informing the user that he/she
-# is about to remove a user profile, and action that cannot be undone.
-PROFILE_REMOVE_TITLE = _("Remove User Profile")
-
 # Translators: Profiles in Orca make it possible for users to quickly switch
 # amongst a group of pre-defined settings (e.g. an 'English' profile for reading
 # text written in English using an English-language speech synthesizer and
