@@ -47,7 +47,6 @@ from . import orca
 from . import orca_state
 from . import script_manager
 from . import settings_manager
-from . import speech
 
 _eventManager = event_manager.getManager()
 _scriptManager = script_manager.getManager()
@@ -141,7 +140,7 @@ class _StringContext:
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
-        voice = self._script.speechGenerator.voice(string=self._string)
+        voice = self._script.speechGenerator.voice(obj=self._obj, string=self._string)
         string = self._script.utilities.adjustForRepeats(self._string)
 
         orca.emitRegionChanged(self._obj, self._start, self._end, orca.MOUSE_REVIEW)
@@ -290,7 +289,7 @@ class _ItemContext:
             self._script.presentationInterrupt()
 
         if self._frame and self._frame != prior._frame:
-            self._script.presentObject(self._frame, alreadyFocused=True, inMouseReview=True)
+            self._script.presentObject(self._frame, alreadyFocused=True, inMouseReview=True, interrupt=True)
 
         if self._script.utilities.containsOnlyEOCs(self._obj):
             msg = "MOUSE REVIEW: Not presenting object which contains only EOCs"
@@ -342,6 +341,15 @@ class MouseReviewer:
             msg = "MOUSE REVIEW ERROR: Gtk+ 3.20 is not available"
             debug.println(debug.LEVEL_INFO, msg, True)
             return
+        except:
+            msg = "MOUSE REVIEW ERROR: Exception getting pointer for default seat."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
+
+        if not self._pointer:
+            msg = "MOUSE REVIEW ERROR: No pointer for default seat."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
 
         if not self._active:
             return
@@ -356,6 +364,11 @@ class MouseReviewer:
     def activate(self):
         """Activates mouse review."""
 
+        if not _mouseReviewCapable:
+            msg = "MOUSE REVIEW ERROR: Wnck is not available"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
+
         # Set up the initial object as the one with the focus to avoid
         # presenting irrelevant info the first time.
         obj = orca_state.locusOfFocus
