@@ -36,7 +36,7 @@ cgettext = gettext.gettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/home/jd/checkout/orca/bld", "share", "locale")
+localedir = "${prefix}/share/locale".replace('${prefix}', '/home/jd/checkout/orca/bld')
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
