@@ -87,7 +87,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
            or obj.getRole() in [pyatspi.ROLE_TOOL_TIP, pyatspi.ROLE_STATUS_BAR]:
             return result
 
-        args['stopAtRoles'] = [pyatspi.ROLE_DOCUMENT_WEB,
+        args['stopAtRoles'] = [pyatspi.ROLE_DOCUMENT_FRAME,
+                               pyatspi.ROLE_DOCUMENT_WEB,
                                pyatspi.ROLE_EMBEDDED,
                                pyatspi.ROLE_INTERNAL_FRAME,
                                pyatspi.ROLE_MATH,
@@ -146,7 +147,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             result = [messages.HAS_POPUP_TREE]
 
         if result:
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         return result
 
@@ -163,7 +164,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         args['stringType'] = 'clickable'
         if self._script.utilities.isClickableElement(obj):
             result = [self._script.formatting.getString(**args)]
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             return result
 
         return []
@@ -214,7 +215,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         args['stringType'] = 'haslongdesc'
         if self._script.utilities.hasLongDesc(obj):
             result = [self._script.formatting.getString(**args)]
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             return result
 
         return []
@@ -235,7 +236,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         args['stringType'] = 'hasdetails'
         result = [self._script.formatting.getString(**args) % toPresent]
-        result.extend(self.voice(speech_generator.SYSTEM))
+        result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
     def _generateAllDetails(self, obj, **args):
@@ -252,19 +253,19 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         args['stringType'] = 'hasdetails'
         result = [self._script.formatting.getString(**args) % ""]
-        result.extend(self.voice(speech_generator.SYSTEM))
+        result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         result = []
         for o in objs:
             result.append(self.getLocalizedRoleName(o))
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
             string = self._script.utilities.expandEOCs(o)
             if not string.strip():
                 continue
 
             result.append(string)
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
             result.extend(self._generatePause(o))
 
         return result
@@ -300,7 +301,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 words = words[0:5] + ['...']
 
             result.append(self._script.formatting.getString(**objArgs) % " ".join(words))
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             result.extend(self._generatePause(o, **objArgs))
 
         return result
@@ -341,7 +342,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 name = self._script.utilities.verbalizeAllPunctuation(name)
 
             result = [name]
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
             return result
 
         if obj.getRole() == pyatspi.ROLE_CHECK_BOX:
@@ -391,7 +392,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     name = name.strip()
                 result = [name]
 
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
             return result
 
         return super()._generateName(obj, **args)
@@ -406,7 +407,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         label, objects = self._script.utilities.inferLabelFor(obj)
         if label:
             result = [label]
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
             return result
 
         return super()._generateLabel(obj, **args)
@@ -431,7 +432,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if self._script.utilities.inDocumentContent(obj) \
            and not self._script.utilities.inDocumentContent(orca_state.locusOfFocus):
             result = ['']
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             return result
 
         return super()._generateLeaving(obj, **args)
@@ -463,7 +464,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         result = [messages.listItemCount(setsize)]
-        result.extend(self.voice(speech_generator.SYSTEM))
+        result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
     # TODO - JD: Yet another dumb generator method we should kill.
@@ -497,12 +498,10 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         result = []
-        acss = self.voice(speech_generator.SYSTEM)
-
         roledescription = self._script.utilities.getRoleDescription(obj)
         if roledescription:
             result = [roledescription]
-            result.extend(acss)
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             return result
 
         role = args.get('role', obj.getRole())
@@ -560,13 +559,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     return []
             if role not in doNotSpeak:
                 result.append(self.getLocalizedRoleName(obj, **args))
-                result.extend(acss)
+                result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         elif isEditable and self._script.utilities.isDocument(obj):
             if obj.parent and not obj.parent.getState().contains(pyatspi.STATE_EDITABLE) \
                and lastKey not in ["Home", "End", "Up", "Down", "Left", "Right", "Page_Up", "Page_Down"]:
                 result.append(object_properties.ROLE_EDITABLE_CONTENT)
-                result.extend(acss)
+                result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         elif role == pyatspi.ROLE_HEADING:
             if index == total - 1 or not self._script.utilities.isFocusableWithMathChild(obj):
@@ -575,26 +574,26 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     result.append(object_properties.ROLE_HEADING_LEVEL_SPEECH % {
                         'role': self.getLocalizedRoleName(obj, **args),
                         'level': level})
-                    result.extend(acss)
+                    result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
                 else:
                     result.append(self.getLocalizedRoleName(obj, **args))
-                    result.extend(acss)
+                    result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         elif self._script.utilities.isLink(obj):
             if obj.parent.getRole() == pyatspi.ROLE_IMAGE:
                 result.append(messages.IMAGE_MAP_LINK)
-                result.extend(acss)
+                result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             else:
                 if self._script.utilities.hasUselessCanvasDescendant(obj):
                     result.append(self.getLocalizedRoleName(obj, role=pyatspi.ROLE_IMAGE))
-                    result.extend(acss)
+                    result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
                 if index == total - 1 or not self._script.utilities.isFocusableWithMathChild(obj):
                     result.append(self.getLocalizedRoleName(obj, **args))
-                    result.extend(acss)
+                    result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         elif role not in doNotSpeak and args.get('priorObj') != obj:
             result.append(self.getLocalizedRoleName(obj, **args))
-            result.extend(acss)
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         if self._script.utilities.isMath(obj) and not self._script.utilities.isMathTopLevel(obj):
             return result
@@ -618,7 +617,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         result = [string]
-        result.extend(self.voice(speech_generator.SYSTEM))
+        result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
     def _generateSiteDescription(self, obj, **args):
@@ -652,7 +651,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 result.append(messages.LINK_DIFFERENT_SITE)
 
         if result:
-            result.extend(self.voice(speech_generator.HYPERLINK))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         return result
 
@@ -710,7 +709,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             stringType='groupindex') \
             % {"index" : position,
                "total" : total})
-        result.extend(self.voice(speech_generator.SYSTEM))
+        result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
     def _generateUnselectedCell(self, obj, **args):
@@ -728,16 +727,16 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             label = self._script.utilities.labelForCellCoordinates(obj)
             if label:
                 result.append(label)
-                result.extend(self.voice(speech_generator.SYSTEM))
+                result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
                 return result
 
             row, col = self._script.utilities.coordinatesForCell(obj)
             if self._script.utilities.cellRowChanged(obj):
                 result.append(messages.TABLE_ROW % (row + 1))
-                result.extend(self.voice(speech_generator.SYSTEM))
+                result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             if self._script.utilities.cellColumnChanged(obj):
                 result.append(messages.TABLE_COLUMN % (col + 1))
-                result.extend(self.voice(speech_generator.SYSTEM))
+                result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
 
         return result
 
@@ -786,6 +785,11 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             document = self._script.utilities.getTopLevelDocumentForObject(obj)
             args['priorObj'] = self._script.utilities.getPriorContext(document)[0]
 
+        start = args.get("startOffset", 0)
+        end = args.get("endOffset", -1)
+        args["language"], args["dialect"] = \
+            self._script.utilities.getLanguageAndDialectForSubstring(obj, start, end)
+
         if not result:
             result = list(filter(lambda x: x, super().generateSpeech(obj, **args)))
 
@@ -823,6 +827,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 string = ""
             else:
                 string = messages.BLANK
-            result = [string, self.voice(speech_generator.DEFAULT)]
+            result = [string, self.voice(speech_generator.DEFAULT, **args)]
 
         return result
