@@ -145,8 +145,14 @@ class SettingsManager(object):
         debug.println(debug.LEVEL_INFO, 'SETTINGS MANAGER: Activated', True)
 
         # Set the active profile and load its stored settings
+        msg = 'SETTINGS MANAGER: Current profile is %s' % self.profile
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         if self.profile is None:
             self.profile = self.general.get('startingProfile')[1]
+            msg = 'SETTINGS MANAGER: Current profile is now %s' % self.profile
+            debug.println(debug.LEVEL_INFO, msg, True)
+
         self.setProfile(self.profile)
 
     def _loadBackend(self):
@@ -281,20 +287,47 @@ class SettingsManager(object):
             lang = "%s_%s" % (lang, dialect.upper())
         return lang
 
+    def getSpeechServerFactories(self):
+        """Imports all known SpeechServer factory modules."""
+
+        factories = []
+        for moduleName in self.getSetting('speechFactoryModules'):
+            try:
+                module = importlib.import_module('orca.%s' % moduleName)
+                factories.append(module)
+                msg = "SETTINGS MANAGER: Valid speech server factory: %s" % moduleName
+                debug.println(debug.LEVEL_INFO, msg, True)
+            except:
+                msg = "SETTINGS MANAGER: Invalid speech server factory: %s" % moduleName
+                debug.println(debug.LEVEL_INFO, msg, True)
+
+        return factories
+
     def _loadProfileSettings(self, profile=None):
         """Get from the active backend all the settings for the current
         profile and store them in the object's attributes.
         A profile can be passed as a parameter. This could be useful for
         change from one profile to another."""
+
+        msg = 'SETTINGS MANAGER: Loading settings for %s profile' % profile
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         if profile is None:
             profile = self.profile
         self.profileGeneral = self.getGeneralSettings(profile) or {}
         self.profilePronunciations = self.getPronunciations(profile) or {}
         self.profileKeybindings = self.getKeybindings(profile) or {}
 
+        msg = 'SETTINGS MANAGER: Settings for %s profile loaded' % profile
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _mergeSettings(self):
         """Update the changed values on the profile settings
         over the current and active settings"""
+
+        msg = 'SETTINGS MANAGER: Merging settings.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         self.profileGeneral.update(self._appGeneral)
         self.profilePronunciations.update(self._appPronunciations)
         self.profileKeybindings.update(self._appKeybindings)
@@ -303,6 +336,9 @@ class SettingsManager(object):
         self.pronunciations.update(self.profilePronunciations)
         self.keybindings.update(self.profileKeybindings)
 
+        msg = 'SETTINGS MANAGER: Settings merged.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _enableAccessibility(self):
         """Enables the GNOME accessibility flag.  Users need to log out and
         then back in for this to take effect.
@@ -318,27 +354,51 @@ class SettingsManager(object):
         return not alreadyEnabled
 
     def isAccessibilityEnabled(self):
-        if not _proxy:
-            return False
+        msg = 'SETTINGS MANAGER: Checking if accessibility is enabled.'
+        debug.println(debug.LEVEL_INFO, msg, True)
 
-        return _proxy.Get('(ss)', 'org.a11y.Status', 'IsEnabled')
+        msg = 'SETTINGS MANAGER: Accessibility enabled: '
+        if not _proxy:
+            rv = False
+            msg += 'Error (no proxy)'
+        else:
+            rv = _proxy.Get('(ss)', 'org.a11y.Status', 'IsEnabled')
+            msg += str(rv)
+
+        debug.println(debug.LEVEL_INFO, msg, True)
+        return rv
 
     def setAccessibility(self, enable):
+        msg = 'SETTINGS MANAGER: Attempting to set accessibility to %s.' % enable
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         if not _proxy:
+            msg = 'SETTINGS MANAGER: Error (no proxy)'
+            debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
         vEnable = GLib.Variant('b', enable)
-        _proxy.Set('(ssv)', 'org.a11y.Status', 'IsEnabled', vEnable)            
+        _proxy.Set('(ssv)', 'org.a11y.Status', 'IsEnabled', vEnable)
+
+        msg = 'SETTINGS MANAGER: Finished setting accessibility to %s.' % enable
+        debug.println(debug.LEVEL_INFO, msg, True)
 
     def isScreenReaderServiceEnabled(self):
         """Returns True if the screen reader service is enabled. Note that
         this does not necessarily mean that Orca (or any other screen reader)
         is running at the moment."""
 
-        if not _proxy:
-            return False
+        msg = 'SETTINGS MANAGER: Is screen reader service enabled? '
 
-        return _proxy.Get('(ss)', 'org.a11y.Status', 'ScreenReaderEnabled')
+        if not _proxy:
+            rv = False
+            msg += 'Error (no proxy)'
+        else:
+            rv = _proxy.Get('(ss)', 'org.a11y.Status', 'ScreenReaderEnabled')
+            msg += str(rv)
+
+        debug.println(debug.LEVEL_INFO, msg, True)
+        return rv
 
     def setStartingProfile(self, profile=None):
         if profile is None:
@@ -353,6 +413,9 @@ class SettingsManager(object):
         Also the settings from that profile will be loading
         and updated the current settings with them."""
 
+        msg = 'SETTINGS MANAGER: Setting profile to: %s' % profile
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         oldVoiceLocale = self.getVoiceLocale('default')
 
         self.profile = profile
@@ -369,16 +432,25 @@ class SettingsManager(object):
             orca_i18n.setLocaleForMessages(newVoiceLocale)
             orca_i18n.setLocaleForGUI(newVoiceLocale)
 
+        msg = 'SETTINGS MANAGER: Profile set to: %s' % profile
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def removeProfile(self, profile):
         self._backend.removeProfile(profile)
 
     def _setSettingsRuntime(self, settingsDict):
+        msg = 'SETTINGS MANAGER: Setting runtime settings.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         for key, value in settingsDict.items():
             setattr(settings, str(key), value)
         self._getCustomizedSettings()
         for key, value in self.customizedSettings.items():
             setattr(settings, str(key), value)
 
+        msg = 'SETTINGS MANAGER: Runtime settings set.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _setPronunciationsRuntime(self, pronunciationsDict):
         pronunciation_dict.pronunciation_dict = {}
         for key, value in pronunciationsDict.values():
@@ -406,6 +478,10 @@ class SettingsManager(object):
     def _setProfileGeneral(self, general):
         """Set the changed general settings from the defaults' ones
         as the profile's."""
+
+        msg = 'SETTINGS MANAGER: Setting general settings for profile'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         self.profileGeneral = {}
 
         for key, value in general.items():
@@ -418,18 +494,35 @@ class SettingsManager(object):
             elif self.general.get(key) != value:
                 self.profileGeneral[key] = value
 
+        msg = 'SETTINGS MANAGER: General settings for profile set'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _setProfilePronunciations(self, pronunciations):
         """Set the changed pronunciations settings from the defaults' ones
         as the profile's."""
+
+        msg = 'SETTINGS MANAGER: Setting pronunciation settings for profile.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         self.profilePronunciations = self.defaultPronunciations.copy()
         self.profilePronunciations.update(pronunciations)
 
+        msg = 'SETTINGS MANAGER: Pronunciation settings for profile set.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _setProfileKeybindings(self, keybindings):
         """Set the changed keybindings settings from the defaults' ones
         as the profile's."""
+
+        msg = 'SETTINGS MANAGER: Setting keybindings settings for profile.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         self.profileKeybindings = self.defaultKeybindings.copy()
         self.profileKeybindings.update(keybindings)
 
+        msg = 'SETTINGS MANAGER: Keybindings settings for profile set.'
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _saveAppSettings(self, appName, general, pronunciations, keybindings):
         appGeneral = {}
         profileGeneral = self.getGeneralSettings(self.profile)
@@ -458,6 +551,9 @@ class SettingsManager(object):
     def saveSettings(self, script, general, pronunciations, keybindings):
         """Save the settings provided for the script provided."""
 
+        msg = 'SETTINGS MANAGER: Saving settings for %s (app: %s)' % (script, script.app)
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         app = script.app
         if app:
             self._saveAppSettings(app.name, general, pronunciations, keybindings)
@@ -477,10 +573,17 @@ class SettingsManager(object):
         self._setProfilePronunciations(pronunciations)
         self._setProfileKeybindings(keybindings)
 
+        msg = 'SETTINGS MANAGER: Saving for backend %s' % self._backend
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         self._backend.saveProfileSettings(self.profile,
                                           self.profileGeneral,
                                           self.profilePronunciations,
                                           self.profileKeybindings)
+
+        msg = 'SETTINGS MANAGER: Settings for %s (app: %s) saved' % (script, script.app)
+        debug.println(debug.LEVEL_INFO, msg, True)
+
         return self._enableAccessibility()
 
     def _adjustBindingTupleValues(self, bindingTuple):
@@ -515,7 +618,7 @@ class SettingsManager(object):
         return self._backend.isFirstStart()
 
     def setFirstStart(self, value=False):
-        """Set firstStart. This user-configurable settting is primarily
+        """Set firstStart. This user-configurable setting is primarily
         intended to serve as an indication as to whether or not initial
         configuration is needed."""
         self._backend.setFirstStart(value)
